aboutsummaryrefslogtreecommitdiff
path: root/sound/decoders/raw.h
diff options
context:
space:
mode:
authorJohannes Schickel2010-01-30 15:29:48 +0000
committerJohannes Schickel2010-01-30 15:29:48 +0000
commit75ba7ee0f84d83175ea105de4ffc53256c5025be (patch)
tree27b75dfd2511c0eb4f90a84b3bc27047f95b23e0 /sound/decoders/raw.h
parent3cc0ef6c1cf5574168456e74736baf8f4e231af6 (diff)
downloadscummvm-rg350-75ba7ee0f84d83175ea105de4ffc53256c5025be.tar.gz
scummvm-rg350-75ba7ee0f84d83175ea105de4ffc53256c5025be.tar.bz2
scummvm-rg350-75ba7ee0f84d83175ea105de4ffc53256c5025be.zip
Rename RawDiskStream to RawAudioStream.
svn-id: r47718
Diffstat (limited to 'sound/decoders/raw.h')
-rw-r--r--sound/decoders/raw.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/sound/decoders/raw.h b/sound/decoders/raw.h
index c81884dc00..5ef3204392 100644
--- a/sound/decoders/raw.h
+++ b/sound/decoders/raw.h
@@ -65,18 +65,18 @@ enum RawFlags {
/**
- * Struct used to define the audio data to be played by a RawDiskStream.
+ * Struct used to define the audio data to be played by a RawAudioStream.
*/
-struct RawDiskStreamAudioBlock {
+struct RawAudioStreamBlock {
int32 pos; ///< Position in stream of the block (in bytes of course!)
int32 len; ///< Length of the block (in sample (pairs))
};
/**
* List containing all blocks of a raw stream.
- * @see RawDiskStreamAudioBlock
+ * @see RawAudioStreamBlock
*/
-typedef Common::List<RawDiskStreamAudioBlock> RawStreamBlockList;
+typedef Common::List<RawAudioStreamBlock> RawStreamBlockList;
/**
* Creates an audio stream, which plays from the given buffer.
@@ -133,8 +133,8 @@ SeekableAudioStream *makeRawStream(Common::SeekableReadStream *stream,
* Creates a audio stream, which plays from given stream.
*
* @param stream Stream to play from
* @param block Pointer to an RawDiskStreamAudioBlock array
* @see RawDiskStreamAudioBlock
* @param numBlocks Number of blocks.
* @param rate The rate
* @param flags Flags combination.
@@ -143,7 +143,7 @@ SeekableAudioStream *makeRawStream(Common::SeekableReadStream *stream,
* @return The new SeekableAudioStream (or 0 on failure).
*/
SeekableAudioStream *makeRawDiskStream_OLD(Common::SeekableReadStream *stream,
- RawDiskStreamAudioBlock *block, int numBlocks,
+ RawAudioStreamBlock *block, int numBlocks,
int rate, byte flags,
DisposeAfterUse::Flag disposeStream);
@@ -133,8 +133,8 @@ SeekableAudioStream *makeRawStream(Common::SeekableReadStream *stream,
*
* @param stream Stream to play from
- * @param block Pointer to an RawDiskStreamAudioBlock array
- * @see RawDiskStreamAudioBlock
+ * @param block Pointer to an RawAudioStreamBlock array
+ * @see RawAudioStreamBlock
* @param numBlocks Number of blocks.
* @param rate The rate